@@ -1400,8 +1400,8 @@ spMsPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         curr.set <- sort(sites.random[sites.k.fold[[i]]])
         if (binom) {
           y.indx <- !(1:J %in% curr.set)
-          y.fit <- y[rep(y.indx, N), drop = FALSE]
-          y.0 <- y[rep(y.indx, N), drop = FALSE]
+          y.fit <- y[rep(y.indx, each = N), drop = FALSE]
+          y.0 <- y[rep(y.indx, each = N), drop = FALSE]
         } else {
           y.indx <- !((z.long.indx + 1) %in% curr.set)
           y.fit <- c(y.big[, -curr.set, , drop = FALSE])
