@@ -32,7 +32,7 @@ extern "C" {
     /**********************************************************************
      * Initial constants
      * *******************************************************************/
-    int i, j, k, s, g, t, h, r, l, info, nProtect=0, ii, ll;    
+    int i, j, k, s, h, l, info, nProtect=0, ii, ll;    
 
     const int inc = 1;
     const double one = 1.0;
@@ -128,8 +128,6 @@ extern "C" {
     int JN = J * N;
     int Nq = N * q;
     int JpOcc = J * pOcc; 
-    int JJ = J * J;
-    int jj, kk;
     int JpOccRE = J * pOccRE; 
     double tmp_0, tmp_02; 
     double *tmp_one = (double *) R_alloc(inc, sizeof(double)); 
@@ -219,7 +217,6 @@ extern "C" {
      * Additional Sampler Prep
      * *******************************************************************/
     // For latent occupancy
-    double psiNum; 
     double *psi = (double *) R_alloc(JN, sizeof(double)); 
     zeros(psi, JN); 
     double *yWAIC = (double *) R_alloc(JN, sizeof(double)); zeros(yWAIC, JN);
