@@ -39,7 +39,7 @@ extern "C" {
     /**********************************************************************
      * Initial constants
      * *******************************************************************/
-    int i, j, k, s, g, t, h, r, l, info, nProtect=0, ii, ll;    
+    int i, j, k, s, h, r, l, info, nProtect=0, ii, ll;    
 
     const int inc = 1;
     const double one = 1.0;
@@ -160,8 +160,6 @@ extern "C" {
     int Nq = N * q;
     int JpOcc = J * pOcc; 
     int nObspDet = nObs * pDet;
-    int JJ = J * J;
-    int jj, kk;
     int JpOccRE = J * pOccRE; 
     int nObspDetRE = nObs * pDetRE;
     double tmp_0, tmp_02; 
